@@ -58,7 +58,7 @@ class VirtualMachine(NamespacedResource):
     def _subresource_api_url(self):
         return (
             f"{self.client.configuration.host}/"
-            f"apis/subresources.kubevirt.io/{self.api().api_version}/"
+            f"apis/subresources.kubevirt.io/{self.api.api_version}/"
             f"namespaces/{self.namespace}/virtualmachines/{self.name}"
         )
 
@@ -111,16 +111,15 @@ class VirtualMachine(NamespacedResource):
             wait_timeout=timeout,
             sleep=sleep,
             exceptions=ProtocolError,
-            func=self.api().get,
+            func=self.api.get,
             field_selector=f"metadata.name=={self.name}",
             namespace=self.namespace,
         )
         for sample in samples:
-            if sample.items:
+            if sample.items and self.ready == status:
                 # VM with runStrategy does not have spec.running attribute
                 # VM status should be taken from spec.status.ready
-                if self.ready == status:
-                    return
+                return
 
     def get_interfaces(self):
         return self.instance.spec.template.spec.domain.devices.interfaces
